Version 0.1.1 (2020-04-20):
 * Don't add times for too shallow Git clones
 * Handle untracked source files, add configuration options
   ``git_untracked_check_dependencies`` and ``git_untracked_show_sourcelink``

Version 0.1.0 (2020-04-08):
   Initial release
